ui

package
v0.0.0-...-c6ca740 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 2, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// DialogTitle is the title for the YAD dialog.
	DialogTitle = "BookmarkIt"
	// DialogText is the text prompt for the YAD dialog.
	DialogText = "Please enter your bookmark and a key"
	// Separator is used by YAD to separate form fields in its output.
	Separator = "___"
)

Variables

This section is empty.

Functions

func GetYADInput

func GetYADInput(clipboardContent string) (key, bookmark string, err error)

GetYADInput prompts the user for a key and a bookmark link using YAD. It pre-fills the bookmark field with clipboardContent.

func ShowFZF

func ShowFZF(options []string, query string) (string, error)

ShowFZF presents a list of options to the user via FZF for fuzzy searching.

Types

This section is empty.

Jump to